@@ -1,4 +1,4 @@
-/* 02dec11abu
+/* 07mar12abu
  * (c) Software Lab. Alexander Burger
  */
 
@@ -190,6 +190,7 @@ function post(form, file) {
                               fld.options[j].disabled = true;
                      }
                      fld.disabled = true;
+                     InBtn = 0;  // 'onblur' on won't come when disabled
                      if (fld.type == "checkbox"  &&  fld.checked)
                         document.getElementsByName(fld.name)[0].value = "T";
                      ++i;
