@@ -1,4 +1,4 @@
-/* 25sep11abu
+/* 07jun12abu
  * (c) Software Lab. Alexander Burger
  */
 
@@ -229,7 +229,8 @@ any doDef(any ex) {
    }
    else {
       x = cdr(x),  Push(c3, EVAL(car(x)));
-      Touch(ex,data(c1));
+      if (!isNil(data(c2)))
+         Touch(ex,data(c1));
       if (!isNil(y = get(data(c1), data(c2)))  &&  !equal(data(c3), y))
          redefMsg(data(c1), data(c2));
       put(data(c1), data(c2), data(c3));
@@ -1170,7 +1171,7 @@ any doAt(any ex) {
    any x;
 
    x = cdr(ex),  x = EVAL(car(x));
-   NeedCell(ex,x);
+   NeedPair(ex,x);
    if (isNil(cdr(x)))
       return Nil;
    NeedCnt(ex,car(x));
